Frequentist estimates of intrinsic hepatic clearance (Clint) for cryopreserved pooled human hepatocyte suspensions. Chemicals were per- and polyfluoroalkyl substance (PFAS) samples. The experiments were led by Dr. Crizer.
crizer2024.clint.L3A level-3 data.frame with 60 rows and 13 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
CalibrationIdentifier for mass spectrometry calibration -- usually the date
ClintFrequentist point estimate for intrinsic hepatic clearance (Clint)
Clint.pValuep-value of the estimated Clint value
FitTest nominal concentrations in the linear regression fit
AICAkaike Information Criterion (AIC) for the linear regression fit
AIC.NullAkaike Information Criterion of the exponential decay assuming a constant rate of decay
Clint.1Intrinsic hepatic clearance at 1 uM (frequentist point estimate)
Clint.10Intrinsic hepatic clearance at 10 uM (frequentist point estimate)
AIC.SatAkaike Information Criterion of the exponential decay with a saturation probability
Sat.pValuep-value of exponential decay with a saturation probability
crizer2024vitroinvitroTKdata