Learn R Programming

invitroTKdata (version 0.0.2)

kreutz2023.uc.L3: kreutz2023category;textualinvitroTKdata Ultracentrifugation Level-3 Data Set

Description

Frequentist estimates of plasma protein binding measured by ultracentrifugation (UC) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Anna Kreutz and Barbara Wetmore.

Usage

kreutz2023.uc.L3

Arguments

Format

A level-3 data.frame with 73 rows and 5 variables:

Compound.Name

Compound name

DTXSID

DSSTox Substance Identifier (CompTox Chemicals Dashboard)

Lab.Compound.Name

Compound as described in the laboratory

Calibration

Identifier for mass spectrometry calibration -- usually the date

Fup

Frequentist point estimate for fraction unbound in plasma (fup)

References

howard2010plasmainvitroTKdata

kreutz2023categoryinvitroTKdata