Mass Spectrometry measurements of plasma protein binding measured by rapid equilibrium dialysis (RED) for per- and poly-fluorinated alkyl substance (PFAS) samples from experiments led by Dr.s Marci Smeltz and Barbara Wetmore.
smeltz2023.redA level-2 data.frame with 3,955 rows and 25 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of RED sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration -- usually the date
Std.ConcConcentration of analytic standard (for calibration curve) (uM)
Test.Nominal.ConcIntended concentration of chemical introduced into RED plate (uM)
Percent.Physiologic.PlasmaPercent of physiological plasma concentration in RED plate (in percent)
TimeTime of sample measurement (h)
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area of internal standard (pixels)
ReplicateIdentifier for replicate series of RED measurements
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
waters2008validationinvitroTKdata
smeltz2023plasmainvitroTKdata