Frequentist estimate of intrinsic hepatic clearance (Clint) measured using in vitro suspensions of pooled primary human hepatocytes shibata2002predictioninvitroTKdata.
wambaugh2019.clint.L3A data.frame with 473 rows and 13 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemical Dashboard)
Lab.Compound.NameCompound as described in the laboratory
CalibrationIdentifier for mass spectrometry calibration - usually the date
ClintFrequentist point estimate for intrinsic hepatic clearance (Clint)
Clint.pValuep-value of the estimated Clint value
FitTest nominal concentrations in the linear regression fit
AICAkaike Information Criterion (AIC) for the linear regression fit
AIC.NullAkaike Information Criterion of the exponential decay assuming a constant rate of decay
Clint.1Intrinsic hepatic clearance at 1 uM (frequentist point estimate)
Clint.10Intrinsic hepatic clearance at 10 uM (frequentist point estimate)
AIC.SatAkaike Information Criterion of the exponential decay with a saturation probability
Sat.pValuep-value of exponential decay with a saturation probability
shibata2002predictioninvitroTKdata
wambaugh2019assessinginvitroTKdata