Mass spectrometry measurements of plasma protein binding using the rapid equilibrium dialysis (RED) assay method waters2008validationinvitroTKdata.
wambaugh2019.redA data.frame 15990 rows and 26 variables:
Lab.Sample.NameSample description used in the laboratory
DateDate sample was acquired
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
Lab.Compound.NameCompound as described in the laboratory
Sample.TypeType of RED sample
Dilution.FactorNumber of times the sample was diluted
CalibrationIdentifier for mass spectrometry calibration - usually the date
ISTD.NameName of compound used as internal standard (ISTD)
ISTD.ConcConcentration of ISTD (uM)
ISTD.AreaPeak area internal standard (pixels)
AreaPeak area of analyte (target compound)
Analysis.MethodGeneral description of chemical analysis method
Analysis.InstrumentInstrument(s) used for chemical analysis
Analysis.ParametersParameters for identifying analyte peak (for example, retention time)
NoteAny laboratory notes about sample
Level0.FileName of data file from laboratory that was used to compile level-0 data.frame
Level0.SheetName of "sheet" (for Excel workbooks) from which the laboratory data were read
TimeTime when sample was measured (h)
Test.Compound.ConcMeasured concentration of analytic standard (for calibration curve) (uM)
Test.Nominal.ConcExpected initial concentration of chemical added to donor side (uM)
Percent.Physiologic.PlasmaPercent of physiology plasma concentration in RED plate (in percent)
Biological.ReplicatesIdentifier for measurements of multiple samples with the same analyte
Technical.ReplicatesIdentifier for measurements of one sample of a compound
ResponseResponse factor (calculated from analyte and ISTD peaks)
VerifiedIf "Y", then sample is included in the analysis. (Any other value causes the data to be ignored.)
waters2008validationinvitroTKdata
wambaugh2019assessinginvitroTKdata