Frequentist estimate of plasma protein binding using the rapid equilibrium dialysis (RED) assay method waters2008validationinvitroTKdata.
wambaugh2019.red.L3A data.frame 368 rows and 4 variables:
Compound.NameCompound name
DTXSIDDSSTox Substance Identifier (CompTox Chemicals Dashboard)
CalibrationIdentifier for mass spectrometry calibration - usually the date
FupFrequentist point estimate for fraction unbound in plasma (fup)
waters2008validationinvitroTKdata
wambaugh2019assessinginvitroTKdata